<?php
  /**
   **  Timeout User (timeout_user) v1.1
   **
   **  By Ray Black III <allah@accessnode.net>
   **  Changes by Paul Lesneiwski <pdontthink@angrynerds.com>
   **  (c) 2001 (GNU GPL - see ../../COPYING)
   **
   **  This plugin monitors page changes in the right-hand frame.
   **  If the right-hand frame doesn't update within a set number
   **  of minutes, then the plugin logs the user out automatically.
   **
   **  To change the timeout, see below.
   **/


   global $timeout_in_minutes, $allow_user_timeout_config, $allow_user_disable;


   // this is the default timeout value for users who have not
   // (or cannot - see below) set their own values 
   //
   $timeout_in_minutes = 120;


   // set this to zero to disallow users to set their own
   // timeout values and give everybody the default timeout
   // that you set above
   //
   $allow_user_timeout_config = 1;


   // set this to zero to prevent users from being able to 
   // turn off/disable timeout functionality (only applicable
   // when $allow_user_timeout_config is enabled)
   //
   $allow_user_disable = 1;

?>
